@@ -1,7 +1,7 @@
 package Ancient;
 use strict;
 use warnings;
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 1;
 
@@ -13,6 +13,8 @@ Ancient - Post-Apocalyptic Perl
 
 =head1 DESCRIPTION
 
+And I saw another angel coming down from heaven, wrapped in a cloud, with a rainbow over his head; his face was like the sun, and his legs like pillars of fire.
+
 This distribution provides ten independent modules:
 
 =over 4
@@ -172,6 +174,34 @@ math functions.
 
 See L<nvec> for full documentation.
 
+=head1 CUSTOM OP OPTIMIZATION
+
+Many functions in Ancient modules are compiled to custom ops at compile time
+for performance. This optimization is transparent - the functions
+work identically whether optimized or not.
+
+=head2 Full Context Support
+
+Custom ops work correctly in all Perl contexts including C<map>, C<grep>,
+C<for>/C<foreach> loops, and C<while> loops - both with the implicit C<$_>
+variable and with explicit lexical loop variables:
+
+    # All of these use optimized custom ops:
+    my @clamped = map { util::clamp($_, 0, 100) } @values;
+    my @existing = grep { file::exists($_) } @paths;
+    my @evens = grep { util::is_even($_) } @numbers;
+    
+    for (@keys) {
+        my $val = $cache->get($_);
+    }
+    
+    for my $i (@nums) {
+        push @results, util::clamp($i, 0, 100);
+    }
+
+The custom ops properly handle both C<$_> (implemented as OP_RV2SV->OP_GV)
+and lexical loop variables (PADSV) in all contexts.
+
 =head1 AUTHOR
 
 LNATION <email@lnation.org>
