@@ -3,7 +3,7 @@ package nvec;
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 require XSLoader;
 XSLoader::load('nvec', $VERSION);
@@ -595,6 +595,47 @@ Cosine similarity (-1 to 1).
 
 Return a string describing the SIMD backend in use (e.g., "NEON", "AVX2", "SSE2", "scalar").
 
+=head1 C API FOR XS MODULES
+
+For XS modules that need direct access to nvec's SIMD operations, include
+C<nvec_api.h>:
+
+    #include "nvec_api.h"
+
+=head2 Object Lifecycle
+
+    Vec* vec_xs_create(pTHX_ IV capacity);    // Create with capacity
+    void vec_xs_destroy(pTHX_ Vec *v);        // Destroy (if not wrapping)
+    Vec* vec_xs_from_sv(pTHX_ SV *sv);        // Extract from Perl SV
+    SV*  vec_xs_wrap(pTHX_ Vec *v);           // Wrap as Perl object
+
+=head2 Data Access
+
+    double* vec_xs_data(Vec *v);              // Get raw buffer pointer
+    IV      vec_xs_len(Vec *v);               // Get length
+
+=head2 SIMD Operations
+
+    void vec_xs_add_impl(double *c, const double *a, const double *b, IV n);
+    void vec_xs_sub_impl(double *c, const double *a, const double *b, IV n);
+    void vec_xs_mul_impl(double *c, const double *a, const double *b, IV n);
+    void vec_xs_div_impl(double *c, const double *a, const double *b, IV n);
+    void vec_xs_scale_impl(double *c, const double *a, double s, IV n);
+    void vec_xs_add_inplace_impl(double *a, const double *b, IV n);
+    void vec_xs_scale_inplace_impl(double *a, double s, IV n);
+    double vec_xs_sum_impl(const double *a, IV n);
+    double vec_xs_dot_impl(const double *a, const double *b, IV n);
+    const char* vec_xs_simd_name(void);
+
+Example (see C<t/xs/nvec_api_test/> for full working code):
+
+    Vec *v = vec_xs_create(aTHX_ 1000);
+    double *data = vec_xs_data(v);
+    for (IV i = 0; i < 1000; i++) data[i] = i * 0.5;
+    v->len = 1000;
+    double sum = vec_xs_sum_impl(data, 1000);
+    SV *sv = vec_xs_wrap(aTHX_ v);  // Ownership transfers to Perl
+
 =head1 AUTHOR
 
 LNATION <email@lnation.org>
