@@ -2,7 +2,7 @@ package
     util;
 use strict;
 use warnings;
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 require XSLoader;
 XSLoader::load('util', $VERSION);
 1;
@@ -944,6 +944,41 @@ Returns undef for empty arrays or non-arrayrefs.
 Returns the last element of the array without slice overhead.
 Returns undef for empty arrays or non-arrayrefs.
 
+=head1 C API FOR XS MODULES
+
+XS modules can register functions with util's export system by including
+C<util_export.h>:
+
+    #include "util_export.h"
+
+=head2 util_register_export_xs
+
+    void util_register_export_xs(pTHX_ const char *name, XSUBADDR_t xs_func);
+
+Register an XS function as a util export. After registration, users can
+import the function via C<use util qw(name)>.
+
+Example (see C<t/xs/util_export_test/> for full working code):
+
+    static XS(xs_my_function) {
+        dXSARGS;
+        // implementation
+        XSRETURN(1);
+    }
+
+    BOOT:
+        util_register_export_xs(aTHX_ "my_function", xs_my_function);
+
+Users can then:
+
+    use util qw(my_function is_array);  # Import your function + util's
+
+=head2 Perl API
+
+    util::register_export($name, \&coderef)  # Register Perl coderef
+    util::has_export($name)                   # Check if registered
+    util::list_exports()                      # List all registered names
+
 =head1 AUTHOR
 
 LNATION <email@lnation.org>
