@@ -456,6 +456,29 @@ static OP* pp_file_atomic_spew(pTHX) {
    Call checkers for compile-time optimization
    ============================================ */
 
+/* 
+ * Check if an op is accessing $_ (the default variable).
+ * This indicates we're likely in map/grep context where custom ops
+ * don't work correctly due to how the op tree is evaluated.
+ * Returns TRUE if the op is rv2sv -> gv for "_".
+ */
+static bool file_op_is_dollar_underscore(pTHX_ OP *op) {
+    if (!op) return FALSE;
+    
+    /* Check for $_ access: rv2sv -> gv for "_" */
+    if (op->op_type == OP_RV2SV) {
+        OP *gvop = cUNOPx(op)->op_first;
+        if (gvop && gvop->op_type == OP_GV) {
+            GV *gv = cGVOPx_gv(gvop);
+            if (gv && GvNAMELEN(gv) == 1 && GvNAME(gv)[0] == '_') {
+                return TRUE;
+            }
+        }
+    }
+    
+    return FALSE;
+}
+
 /* 1-arg call checker (slurp, exists, size, is_file, is_dir, lines) */
 static OP* file_call_checker_1arg(pTHX_ OP *entersubop, GV *namegv, SV *ckobj) {
     file_ppfunc ppfunc = (file_ppfunc)SvIVX(ckobj);
@@ -480,6 +503,11 @@ static OP* file_call_checker_1arg(pTHX_ OP *entersubop, GV *namegv, SV *ckobj) {
     /* Verify exactly 1 arg */
     if (OpSIBLING(argop) != cvop) return entersubop;
 
+    /* If arg is $_, fall back to XS (map/grep context) */
+    if (file_op_is_dollar_underscore(aTHX_ argop)) {
+        return entersubop;
+    }
+
     /* Detach arg from tree */
     OpMORESIB_set(pushop, cvop);
     OpLASTSIB_set(argop, NULL);
@@ -519,6 +547,11 @@ static OP* file_call_checker_2arg(pTHX_ OP *entersubop, GV *namegv, SV *ckobj) {
     /* Verify exactly 2 args */
     if (OpSIBLING(dataop) != cvop) return entersubop;
 
+    /* If path is $_, fall back to XS (map/grep context) */
+    if (file_op_is_dollar_underscore(aTHX_ pathop)) {
+        return entersubop;
+    }
+
     /* Detach args from tree */
     OpMORESIB_set(pushop, cvop);
     OpLASTSIB_set(pathop, NULL);
