@@ -393,6 +393,28 @@ static OP* pp_lru_func_delete(pTHX) {
 
 typedef OP* (*lru_ppfunc)(pTHX);
 
+/* 
+ * Check if an op is accessing $_ (the default variable).
+ * This indicates we're likely in map/grep context where custom ops
+ * don't work correctly due to how the op tree is evaluated.
+ */
+static bool lru_op_is_dollar_underscore(pTHX_ OP *op) {
+    if (!op) return FALSE;
+    
+    /* Check for $_ access: rv2sv -> gv for "_" */
+    if (op->op_type == OP_RV2SV) {
+        OP *gvop = cUNOPx(op)->op_first;
+        if (gvop && gvop->op_type == OP_GV) {
+            GV *gv = cGVOPx_gv(gvop);
+            if (gv && GvNAMELEN(gv) == 1 && GvNAME(gv)[0] == '_') {
+                return TRUE;
+            }
+        }
+    }
+    
+    return FALSE;
+}
+
 /* 
  * Call checker for 2-arg functions: lru_exists($cache, $key), etc.
  * Uses newBINOP like object.c does for 2-arg calls.
@@ -423,6 +445,12 @@ static OP* lru_func_call_checker_2arg(pTHX_ OP *entersubop, GV *namegv, SV *ckob
     /* Verify exactly 2 args (keyop's sibling is cvop) */
     if (OpSIBLING(keyop) != cvop) return entersubop;
 
+    /* If either arg is $_, fall back to XS (map/grep context) */
+    if (lru_op_is_dollar_underscore(aTHX_ cacheop) ||
+        lru_op_is_dollar_underscore(aTHX_ keyop)) {
+        return entersubop;
+    }
+
     /* Detach cache and key from the entersub tree */
     OpMORESIB_set(pushop, cvop);
     OpLASTSIB_set(keyop, NULL);
@@ -471,6 +499,13 @@ static OP* lru_func_call_checker_3arg(pTHX_ OP *entersubop, GV *namegv, SV *ckob
     /* Verify exactly 3 args (valop's sibling is cvop) */
     if (OpSIBLING(valop) != cvop) return entersubop;
 
+    /* If any arg is $_, fall back to XS (map/grep context) */
+    if (lru_op_is_dollar_underscore(aTHX_ cacheop) ||
+        lru_op_is_dollar_underscore(aTHX_ keyop) ||
+        lru_op_is_dollar_underscore(aTHX_ valop)) {
+        return entersubop;
+    }
+
     /* Detach args from the entersub tree */
     OpMORESIB_set(pushop, cvop);
     
