@@ -860,7 +860,7 @@ static XS(xs_object_new_fallback) {
     sv_bless(obj_sv, meta->stash);
     /* Magic for lock/freeze is added lazily when first needed */
 
-    ST(0) = obj_sv;
+    ST(0) = sv_2mortal(obj_sv);
     XSRETURN(1);
 }
 
